as.merged.dataframe: Exports a synthetic population as one unique dataframe

Description Usage Arguments Author(s)

Description

Merges the individual dataframes of population A, B and links into one unique merged one. There will be partial lines when one entity had no link.

Usage

1

Arguments

generated

the generation result produced by matching.generate

Author(s)

Samuel Thiriot <samuel.thiriot@res-ear.ch>


samthiriot/gosp.dpp documentation built on May 18, 2019, 3:44 p.m.