Description Usage Arguments Value Author(s) See Also
Generates a synthetic population based on the resolution of the problem,
applied on two samples sample.A and sample.B.
It first resizes the two populations so they reach the expected sizes,
the adds degrees to them, then creates links based on degrees
and characteristics.
1 2 | matching.generate(case, sample.A, sample.B, verbose = FALSE,
force = FALSE)
|
case |
the case resolved by the |
sample.A |
the sample to use as population A |
sample.B |
the sample to use as population B |
verbose |
displays detailed messages if TRUE |
force |
if TRUE, will try to generate even very big populations (and will likely fail) |
the generated population
Samuel Thiriot <samuel.thiriot@res-ear.ch>
matching.solve to prepare the case for this call
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.