measure_pairing_from_df: Create pairing probabilities

Description Usage Arguments Value Author(s)

Description

Takes a dataframe containing a sample, and extracts a joint probabilitie table ready to be passed to create_matching_probabilities_table.

Usage

1
measure_pairing_from_df(df, var.row, var.col, var.weight)

Arguments

df

the dataframe

var.row

the variables to use as rows

var.col

the variables to use as cols

var.weight

the name of the variable to use for weight

Value

a dataframe structured in two dimensions as joint probabilities

Author(s)

Samuel Thiriot <samuel.thiriot@res-ear.ch>


samthiriot/gosp.dpp documentation built on May 18, 2019, 3:44 p.m.