propagate.direct: Completes a partial solution by inference

Description Usage Arguments Value Author(s) See Also

Description

Takes an incomplete solution and enriches by applying the equations. For instance if an equation links hat.di * hat.ci = hat.ni, then this equation will be applied if two of these variables are available.

Usage

1
2
propagate.direct(sol, case, precision.pd = .Machine$double.eps,
  verbose = FALSE, indent = 1)

Arguments

sol

the current solution (a named list)

case

the case to solve

precision.pd

the precision to be used for probabilistic distributions of degrees comparisons

verbose

if TRUE, will display detailed information on the console

indent

the level of indentation for verbose messages

Value

a solution with possibly more variables known

Author(s)

Samuel Thiriot <samuel.thiriot@res-ear.ch>

See Also

this function relies on round_sum to round values so their sums is preserved; normalise to normalise variables; update_degree_distribution to compute the detail of degree distributions from average degrees.


samthiriot/gosp.dpp documentation built on May 18, 2019, 3:44 p.m.