Description Usage Arguments Value Author(s)
Resolves a given case starting with the base solution
according to user parameters.
It first uses propagate.direct to infer
results from available elements; then it detects the
chains of variable which are not constrained enough to be solved this way
using detect.missing.chains. Then it solves each chain
iteratively until the entire problem is solved.
1 2 3 |
sol |
the current solution (a named list) |
case |
the case to solve |
nA |
the target population size for A |
nB |
the target population size for B |
nu.A |
control for nA: 0 means "respect nA", non-null "adapt it to solve the case" |
phi.A |
control for frequencies: 0 means "respect the original frequencies as detected in the sample", non-null "adapt it to solve the case" |
delta.A |
control for degree A: 0 means "respect the input parameters pdi", non-null "adapt them to solve the case" |
gamma |
control for pij: 0 means "respect the matching probabilities pij", non-null "adapt them to solve the case" |
nu.B |
control for nB: 0 means "respect nB", non-null "adapt it to solve the case" |
phi.B |
control for frequencies: 0 means "respect the original frequencies as detected in the sample", non-null "adapt it to solve the case" |
delta.B |
control for degree B: 0 means "respect the input parameters pdj", non-null "adapt them to solve the case" |
verbose |
if TRUE, will display detailed information on the console |
tolerance.pd |
the tolerance for probability distributions |
tolerance.degree.max |
the tolerance for min/max average degrees |
tolerance.pij |
the tolerance for pij probabilities |
a list of vectors (the chains) of strings
Samuel Thiriot <samuel.thiriot@res-ear.ch>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.