Description Usage Arguments Value Author(s)
Takes a dataframe containing a sample, and extracts a joint probabilitie table
ready to be passed to create_matching_probabilities_table.
1 | measure_pairing_from_df(df, var.row, var.col, var.weight)
|
df |
the dataframe |
var.row |
the variables to use as rows |
var.col |
the variables to use as cols |
var.weight |
the name of the variable to use for weight |
a dataframe structured in two dimensions as joint probabilities
Samuel Thiriot <samuel.thiriot@res-ear.ch>
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.